@@ -98,13 +98,11 @@ class VerifyToken:
                     if self.role_db:
                         # 添加权限集合信息到角色集合
                         for status in (0, 1, 2, 3):
-                            permissions_set = find_dict.update(
-                                {'permission_status': status})
-                            if not self.role_db.does_it_exist(permissions_set):
-                                permissions_set.update(
+                            find_dict.update({'permission_status': status})
+                            if not self.role_db.does_it_exist(find_dict):
+                                find_dict.update(
                                     {'permission_id': purview_name_id})
-                                self.role_db.write_one_docu(
-                                    docu=permissions_set)
+                                self.role_db.write_one_docu(docu=find_dict)
                     else:
                         logging.error('计算组件未建立连接/依赖到认证中心，无法注册对应的角色')
             except Exception as e:
